<?php
/**
 * montonio/module-shipping
 *
 * @category   montonio
 * @package    module-shipping
 * @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
 * @license    https://www.gnu.org/licenses/gpl-3.0.txt
 */

namespace Montonio\Shipping\Block\Adminhtml\System\Config\Form\Field;

/**
 * @inheritdoc
 */
class AvailableMethods extends \Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray
{
    /**
     * Styles to apply to disabled field to allow field save.
     */
    private const DISABLED_FIELD_STYLES = [
        'width: 50px',
        'pointer-events: none',
        'background-color: #e9e9e9',
        'border-color: #adadad',
        'color: #303030',
        'opacity: .5',
        'cursor: not-allowed',
    ];

    /**
     *
     * @param \Magento\Framework\View\Element\BlockFactory $blockFactory
     * @param \Magento\Framework\Data\Form\Element\Factory $elementFactory
     * @param \Magento\Framework\View\Design\Theme\LabelFactory $labelFactory
     * @param \Magento\Backend\Block\Template\Context $context
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\View\Element\BlockFactory $blockFactory,
        \Magento\Framework\Data\Form\Element\Factory $elementFactory,
        \Magento\Framework\View\Design\Theme\LabelFactory $labelFactory,
        \Magento\Backend\Block\Template\Context $context,
        array $data = []
    ) {

        $this->blockFactory = $blockFactory;
        $this->elementFactory = $elementFactory;
        $this->labelFactory = $labelFactory;

        $this->setTemplate('Montonio_Shipping::system/config/form/field/array.phtml');

        parent::__construct($context, $data);
    }

    public function getArrayRows()
    {
        $values = $this->getElement()->getValue() ?? [];

        $this->getElement()->setValue($values);

        return parent::getArrayRows();
    }


    /**
     * Sort array by field.
     *
     * @param array $array
     * @param string $field
     *
     * @return array
     */
    public function sortArrayByField(array $array, string $field): array
    {
        $output = [];
        $undefined = [];

        foreach ($array as $data) {
            if (empty($data[$field])) {
                $undefined['undefined'][] = $data;
            } else {
                $output[$data[$field]][] = $data;
            }
        }

        return $undefined + $output;
    }


    /**
     * Prepare to render
     *
     * @return void
     */
    public function _prepareToRender(): void
    {
        $this->addColumn('method_country', [
            'label' => __('Country'),
            'style' => \implode(';', self::DISABLED_FIELD_STYLES),
        ]);

        $this->addColumn('method_type', [
            'label' => __('Type'),
            'style' => \implode(';', self::DISABLED_FIELD_STYLES).';display:none',
        ]);

        $this->addColumn('method_provider', [
            'label' => __('Provider'),
            'style' => \implode(';', self::DISABLED_FIELD_STYLES).';display:none',
        ]);

        $this->addColumn('method_enabled', [
            'label' => __('On/Off'),
            'style' => 'width: 15px'
        ]);

        $this->addColumn('method_title', [
            'label' => __('Title'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_name', [
            'label' => __('Method Name'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_price', [
            'label' => __('Price'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_free_shipping_enabled', [
            'label' => __('Free Shipping with Minimum Order Amount'),
            'style' => 'width: 15px'
        ]);

        $this->addColumn('method_free_shipping_price', [
            'label' => __('Minimum Order Amount for Free Shipping'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_package_measurements_check_enabled', [
            'label' => __('Enable package measurements check'),
            'style' => 'width: 15px'
        ]);

        $this->addColumn('method_package_maximum_weight', [
            'label' => __('Maximum weight (kg)'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_hide_no_measurements_enabled', [
            'label' => __('Hide when no measurements'),
            'style' => 'width: 15px'
        ]);

        $this->addColumn('sort_order', [
            'label' => __('Sort Order'),
            'style' => 'width: 45px',
            'class' => 'validate-number',
        ]);

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add Fields');
    }

    /**
     * Render array cell for prototypeJS template
     *
     * @param string $columnName
     * @return string
     */
    public function renderCellTemplate($columnName)
    {
        if (($columnName == 'method_enabled'
                || $columnName == 'method_free_shipping_enabled'
                || $columnName == 'method_package_measurements_check_enabled'
                || $columnName == 'method_hide_no_measurements_enabled'

            ) && isset($this->_columns[$columnName])) {
            /** @var $label \Magento\Framework\View\Design\Theme\Label */
            $label = $this->labelFactory->create();
            $options = ['0' => __('Off'), '1' => __('On')];
            $element = $this->elementFactory->create('select');
            $element->setForm($this->getForm())
                ->setName($this->_getCellInputElementName($columnName))
                ->setHtmlId($this->_getCellInputElementId('<%- _id %>', $columnName))
                ->setValues($options);
            return str_replace("\n", '', $element->getElementHtml());
        }


        return parent::renderCellTemplate($columnName);
    }

    /**
     * Do nothing
     * @return void
     */
    public function silence() : void
    {
    }
}
