<?php
/**
 * montonio/module-shipping
 *
 * @category   montonio
 * @package    module-shipping
 * @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
 * @license    https://www.gnu.org/licenses/gpl-3.0.txt
 */

namespace Montonio\Shipping\Block\Adminhtml\System\Config;

use Magento\Backend\Block\Widget\Button;
use Magento\Config\Block\System\Config\Form\Field;
use Magento\Framework\Data\Form\Element\AbstractElement;
use Magento\Framework\Exception\LocalizedException;

class UpdateMethodsButton extends Field
{
    /**
     * @var UrlInterface
     */
    private $backendUrl;

    /**
     * Construct function.
     *
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Backend\Model\UrlInterface $backendUrl
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Backend\Model\UrlInterface $backendUrl,
        array $data = [])
    {
        parent::__construct($context, $data);
        $this->backendUrl = $backendUrl;
    }

    /**
     * @inheritdoc
     */
    public function _getElementHtml(AbstractElement $element)
    {
        try {
            /** @var Button $button */
            $button = $this->getLayout()->createBlock(Button::class);

            return $button->setData([
                'label' => $element->getData('label'),
                'onclick' => sprintf(
                    'setLocation("%s");', $this->backendUrl->getUrl('montonio_shipping/configuration/connection')
                ),
            ])->toHtml();
        } catch (LocalizedException $exception) {
            return '';
        }
    }
}
