<?php
/**
 * montonio/module-shipping
 *
 * @category   montonio
 * @package    module-shipping
 * @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
 * @license    https://www.gnu.org/licenses/gpl-3.0.txt
 */

namespace Montonio\Shipping\Controller\Adminhtml\Order;

use Montonio\Shipping\Gateway\Export\OrderExport;
use Exception;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Sales\Api\OrderRepositoryInterface;

class Export extends Action
{
    /**
     * @var OrderExport
     */
    private $export;

    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;

    /**
     * Construct function.
     *
     * @param Context $context
     * @param OrderExport $export
     * @param OrderRepositoryInterface $orderRepository
     */
    public function __construct(Action\Context $context, OrderExport $export, OrderRepositoryInterface $orderRepository)
    {
        parent::__construct($context);

        $this->export = $export;
        $this->orderRepository = $orderRepository;
    }

    /**
     * @inheritdoc
     */
    public function execute()
    {
        $orderId = $this->getRequest()->getParam('order_id');
        try {
            if ($this->export->export($this->orderRepository->get($orderId)) !== false) {
                $this->messageManager->addSuccessMessage(__('Order was successfully exported.'));
            } else {
                $this->messageManager->addErrorMessage(__('There was an error exporting order. Please, check logs.'));
            }
        } catch (Exception $e) {
            $this->messageManager->addExceptionMessage($e, __('Something went wrong while exporting order.'));
        }

        return $this->resultRedirectFactory->create()->setPath('sales/order/view', [
            'order_id' => $orderId,
        ]);
    }
}
