<?php
/**
 * montonio/module-shipping
 *
 * @category   montonio
 * @package    module-shipping
 * @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
 * @license    https://www.gnu.org/licenses/gpl-3.0.txt
 */

namespace Montonio\Shipping\Controller\Adminhtml\Order;

use Montonio\Shipping\Gateway\Export\PrintLabel;
use Exception;
use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Sales\Api\OrderRepositoryInterface;

class Label extends Action
{
    /**
     * @var PrintLabel
     */
    private $printLabel;

    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;

    /**
     * Construct function.
     *
     * @param Context $context
     * @param PrintLabel $printLabel
     * @param OrderRepositoryInterface $orderRepository
     */
    public function __construct(Action\Context $context, PrintLabel $printLabel, OrderRepositoryInterface $orderRepository)
    {
        parent::__construct($context);

        $this->printLabel = $printLabel;
        $this->orderRepository = $orderRepository;
    }

    /**
     * @inheritdoc
     */
    public function execute()
    {

        $orderId = $this->getRequest()->getParam('order_id');
        try {
            if (($result = $this->printLabel->printLabel($this->orderRepository->get($orderId))) !== false) {
                $this->messageManager->addSuccessMessage(__('Label was successfully printed.'));
                if(isset($result->url))
                    return $this->resultRedirectFactory->create()->setPath($result->url);
            } else {
                $this->messageManager->addErrorMessage(__('A label printing error has occurred. Please, check logs.'));
            }
        } catch (Exception $e) {
            $this->messageManager->addExceptionMessage($e, __('Something went wrong while printing the label.'));
        }


        return $this->resultRedirectFactory->create()->setPath('sales/order/view', [
            'order_id' => $orderId,
        ]);
    }
}
