<?php
/**
 * montonio/module-shipping
 *
 * @category   montonio
 * @package    module-shipping
 * @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
 * @license    https://www.gnu.org/licenses/gpl-3.0.txt
 */

namespace Montonio\Shipping\Gateway\Export;
use Magento\Sales\Api\Data\OrderInterface;

class OrderExport
{
    protected $logger;
    protected $config;
    protected $montonioSDK;

    public function __construct(
        \Psr\Log\LoggerInterface $logger,
        \Montonio\Shipping\Gateway\Shippings\Config\Config $config,
        \Montonio\Shipping\Gateway\Shippings\MontonioSDK $montonioSDK
    )
    {
        $this->logger = $logger;
        $this->config = $config;
        $this->montonioSDK = $montonioSDK;
    }

    public function export(OrderInterface $order, $async = false)
    {
        $data = $this->getCreateShipmentData($order);
        $result = $this->montonioSDK->postShipment($data, $async);

        if ($result !== false) {
            $comment = 'Shipping was successfully exported to Montonio';

        } else {
            $comment = 'An error occurred while shipping exporting to Montonio';
        }

        $order->addStatusHistoryComment($comment)->setIsCustomerNotified(null);
        $order->save();
    }

    protected function getCreateShipmentData($order)
    {
        $billingAddress = $shippingAddress = $order->getBillingAddress();
        if ($order->getShippingAddress() && $order->getShippigAddressId() !== $order->getBillingAddressId())
            $shippingAddress = $order->getShippingAddress();

        $shippingMethodIdentifier = $order->getShippingMethod();
        $shippingMethodIdentifier = str_replace('montonio_shipping_', '', $shippingMethodIdentifier);
        $shippingMethodIdentifier = str_replace('EE_', '', $shippingMethodIdentifier);
        $shippingMethodIdentifier = str_replace('LV_', '', $shippingMethodIdentifier);
        $shippingMethodIdentifier = str_replace('LT_', '', $shippingMethodIdentifier);
        $shippingMethodIdentifier = str_replace('FI_', '', $shippingMethodIdentifier);
        $data = array(
            'sender_name'               => (string) $this->config->getValue('sender_info/sender_name'),
            'sender_phone_number'       => (string) $this->config->getValue('sender_info/sender_phone'),
            'sender_street_address_1'   => (string) $this->config->getValue('sender_info/sender_street_address_1'),
            'sender_locality'           => (string) $this->config->getValue('sender_info/sender_locality'),
            'sender_postal_code'        => (string) $this->config->getValue('sender_info/sender_postal_code'),
            'sender_region'             => (string) $this->config->getValue('sender_info/sender_region'),
            'sender_country'            => (string) $this->config->getValue('sender_info/sender_country'),
            'merchant_reference'        => (string) $order->getIncrementId(),
            'shipping_method'           => (string) $shippingMethodIdentifier,
            'billing_first_name'        => (string) $billingAddress->getFirstname(),
            'billing_last_name'         => (string) $billingAddress->getLastname(),
            'billing_company'           => (string) $billingAddress->getCompany(),
            'billing_street_address_1'  => (string) is_array($street = $billingAddress->getStreet()) ? implode(PHP_EOL, $street) : $street,
            'billing_locality'          => (string) $billingAddress->getCity(),
            'billing_postal_code'       => (string) $billingAddress->getPostcode(),
            'billing_country'           => (string) $billingAddress->getCountryId(),
            'billing_email'             => (string) $billingAddress->getEmail(),
            'billing_phone_number'      => (string) $shippingAddress->getTelephone(),
            'shipping_first_name'       => (string) $shippingAddress->getFirstname(),
            'shipping_last_name'        => (string) $shippingAddress->getLastname(),
            'shipping_company'          => (string) $shippingAddress->getCompany(),
            'shipping_street_address_1' => (string) is_array($street = $billingAddress->getStreet()) ? implode(PHP_EOL, $street) : $street,
            'shipping_locality'         => (string) $shippingAddress->getCity(),
            'shipping_postal_code'      => (string) $shippingAddress->getPostcode(),
            'shipping_country'          => (string) $shippingAddress->getCountryId(),
            'shipping_email'            => (string) $shippingAddress->getEmail(),
            'shipping_phone_number'     => (string) $shippingAddress->getTelephone()
        );

        if(strpos($shippingMethodIdentifier, 'courier') === false)
            $data['pickup_point_uuid'] = $order->getMontonioShippingPoint();

        $parcelWeight = 0;
        foreach ($order->getItems() as $item) {
            //we need only single simple, configurable and bundle parent items
            if (isset($item->getData('product_options')['info_buyRequest']['product']) && $item->getProductId() !== $item->getData('product_options')['info_buyRequest']['product']
            ) {
                continue;
            }

            $parcelWeight += (float) $item->getWeight() * $item->getQtyOrdered() * $this->config->getWeightMultiplier();
        }

        $data['parcels'] = array(
            array(
                'weight' => $parcelWeight
            )
        );

        return $data;
    }

}