<?php
/**
 * montonio/module-shipping
 *
 * @category   montonio
 * @package    module-shipping
 * @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
 * @license    https://www.gnu.org/licenses/gpl-3.0.txt
 */

namespace Montonio\Shipping\Model\Observer;
use Magento\Framework\Event\ObserverInterface;
use Throwable;

class PaymentAfter implements ObserverInterface
{
    protected $logger;
    protected $config;
    protected $service;
    protected $session;
    protected $orderExport;

    public function __construct(
        \Magento\Framework\Session\SessionManagerInterface $session,
        \Psr\Log\LoggerInterface $logger,
        \Montonio\Shipping\Gateway\Shippings\Config\Config $config,
        \Montonio\Shipping\Gateway\Export\OrderExport $orderExport
    )
    {
        $this->session = $session;
        $this->logger = $logger;
        $this->config = $config;
        $this->orderExport = $orderExport;
    }

    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $this->session->start();

        $sendType = $this->config->getValue('send_type');
        if ($sendType != \Montonio\Shipping\Model\Adminhtml\Source\Sendtype::montonio_MAIN_AFTER_PAYMENT)  {
            return;
        }
        /* @var $order \Magento\Sales\Model\Order */
        $order = $observer->getEvent()->getOrder();
        if(!empty($this->session->getMontonioShipmentProcessStarted()) && $this->session->getMonotnioShipmentProcessStarted() == $order->getId()) {
            return;
        }

        if(strpos($order->getShippingMethod(), 'montonio_shipping') === false)
            return;

        if ($order->getState() === 'processing' && $order->getOrigData('state') !== 'processing') {
            $this->session->getMontonioShipmentProcessStarted($order->getId());
            try {
                $this->orderExport->export($order, true);
            } catch (Throwable $exception) {
                $this->logger->error('There was an error performing order export.', [
                    'exception_message' => $exception->getMessage(),
                    'order_increment_id' => $order->getIncrementId(),
                ]);
            }
        }
    }

}