<?php
/**
 * montonio/module-shipping
 *
 * @category   montonio
 * @package    module-shipping
 * @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
 * @license    https://www.gnu.org/licenses/gpl-3.0.txt
 */

namespace Montonio\Shipping\Model\Observer;

use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;
use Montonio\Shipping\Model\ShippingPoints;
use Montonio\Shipping\Model\ShippingPointsFactory;

class SaveQuoteDataToOrder implements ObserverInterface
{
    /**
     * @var \Magento\Quote\Model\QuoteRepository
     */
    protected $quoteRepository;

    protected $shippingPointsFactory;

    protected $config;


    /**
     * @param \Magento\Quote\Api\CartRepositoryInterface $quoteRepository
     * @param ShippingPointsFactory $shippingPointsFactory
     */
    public function __construct(
        \Magento\Quote\Api\CartRepositoryInterface $quoteRepository,
        \Montonio\Shipping\Gateway\Shippings\Config\Config $config,
        ShippingPointsFactory $shippingPointsFactory
    ) {
        $this->quoteRepository = $quoteRepository;
        $this->shippingPointsFactory = $shippingPointsFactory;
        $this->config = $config;
    }

    public function execute(EventObserver $observer)
    {
        $order = $observer->getOrder();
        $storeId = $order->getStoreId();

        $method = $order->getShippingMethod();

            if(strpos($method,'montonio_shipping') !== false){
            $order->setCanSendNewEmailFlag(true);
            $quote = $this->quoteRepository->get($order->getQuoteId());
            $point = $quote->getMontonioShippingPoint();

                $parcelPoint = $this->shippingPointsFactory->create();
                $parcelPoint->load($point);



            if ($point) {
                $order->setMontonioShippingPoint($point);
                $montonioMethods = $this->config->getAvailableMethods('', $storeId);

                $title = $parcelPoint->getShippingCode();

                if(isset($montonioMethods[$parcelPoint->getShippingCode()])) {
                    $method = $montonioMethods[$parcelPoint->getShippingCode()];
                    $title = $method['method_title'] . ' ' . $method['method_name'];
                }

                $order->setShippingDescription($title . ' - ' .$parcelPoint->getName());
            }
        }
        return $this;
    }
}
