<?php

namespace Montonio\Shipping\Plugin\Adminhtml;

use Magento\Sales\Block\Adminhtml\Order\View;
use Montonio\Shipping\Gateway\Export\OrderExport;
use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Framework\App\RequestInterface;

class OrderViewPage
{
    /**
     * @var OrderExport
     */
    private $export;

    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;

    /**
     * @var RequestInterface
     */
    private $request;


    /**
     * Construct function.
     *
     * @param Context $context
     * @param OrderExport $export
     * @param OrderRepositoryInterface $orderRepository
     * @param RequestInterface $request
     */
    public function __construct(OrderExport $export, OrderRepositoryInterface $orderRepository, RequestInterface $request)
    {
        $this->export = $export;
        $this->orderRepository = $orderRepository;
        $this->request = $request;
    }

    /**
     * @param View $subject
     */
    public function beforeSetLayout(View $subject)
    {
        $orderId = $this->request->getParam('order_id');
        $order = $this->orderRepository->get($orderId);

        //show buttons only form Montonio shippings
        if(strpos($order->getShippingMethod(), 'montonio_shipping') === false)
            return;

        $subject->addButton(
            'order_montonio_export',
            [
                'label' => __('Export to Montonio Shipping'),
                'onclick' => 'setLocation(\'' . $subject->getUrl('montonio_shipping/order/export') . '\')',
            ]
        );

        //show print label button if created tracking codes
        if(empty($order->getData('montonio_tracking_info')))
            return;

        $subject->addButton(
            'order_montonio_print_label',
            [
                'label' => __('Print Montonio Shipping label'),
                'onclick' => 'setLocation(\'' . $subject->getUrl('montonio_shipping/order/label') . '\')',
            ]
        );
    }
}
