<?php
/**
* montonio/module-shipping
*
* @category   montonio
* @package    module-shipping
* @copyright  Copyright (c) 2020 Montonio Finance OÜ  (https://montonio.com/)
* @license    https://www.gnu.org/licenses/gpl-3.0.txt
*/

namespace Montonio\Shipping\Setup;

use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\UpgradeDataInterface;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Eav\Api\AttributeRepositoryInterface;


class UpgradeData implements UpgradeDataInterface
{

    /**
     * EAV setup factory
     *
     * @var EavSetupFactory
     */
    private $eavSetupFactory;

    /**
     * EAV setup factory
     *
     * @var EavSetupFactory
     */
    private $eavAttributeSetupInterface;

    /**
     * Init
     *
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(EavSetupFactory $eavSetupFactory, AttributeRepositoryInterface $eavAttributeSetupInterface)
    {
        $this->eavSetupFactory = $eavSetupFactory;
        $this->eavAttributeSetupInterface = $eavAttributeSetupInterface;
    }

    public function upgrade(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        if (version_compare($context->getVersion(), '1.0.2') < 0) {
            /** @var EavSetup $eavSetup */
            $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

            $attributesExist = true;

            try {
                $this->eavAttributeSetupInterface->get(\Magento\Catalog\Model\Product::ENTITY, 'nomontonioshipping');
                $attributesExist = true;
            }
            catch (\Magento\Framework\Exception\NoSuchEntityException $e) {
                $attributesExist = false;
            }

            if (!$attributesExist) {
                $eavSetup->addAttribute(
                    \Magento\Catalog\Model\Product::ENTITY,
                    'nomontonioshipping',
                    [
                        'group' => 'General',
                        'type' => 'text',
                        'input' => 'multiselect',
                        'model' => 'Magento\Catalog\Model\ResourceModel\Eav\Attribute',
                        'backend' => 'Magento\Eav\Model\Entity\Attribute\Backend\ArrayBackend',
                        'source' => 'Magento\Eav\Model\Entity\Attribute\Source\Table',
                        'label' => 'Montonio shipping terminals denied',
                        'global' => \Magento\Catalog\Model\ResourceModel\Eav\Attribute::SCOPE_GLOBAL,
                        'visible' => true,
                        'required' => false,
                        'user_defined' => false,
                        'used_in_product_listing' => true,
                        'default' => null,
                        'option' => ['value' =>
                            [
                                'EE_omniva_post_office'=>[
                                    0 => 'EE_omniva_post_office'
                                ],
                                'EE_omniva_parcel_machine'=>[
                                    0 => 'EE_omniva_parcel_machine'
                                ],
                                'EE_omniva_courier'=>[
                                    0 => 'EE_omniva_courier'
                                ],
                                'EE_itella_parcel_machine'=>[
                                    0 => 'EE_itella_parcel_machine'
                                ],
                                'EE_itella_courier'=>[
                                    0 => 'EE_itella_courier'
                                ],
                                'EE_dpd_parcel_machine'=>[
                                    0 => 'EE_dpd_parcel_machine'
                                ],
                                'EE_dpd_courier'=>[
                                    0 => 'EE_dpd_courier'
                                ],
                                'FI_itella_parcel_machine'=>[
                                    0 => 'FI_itella_parcel_machine'
                                ],
                                'FI_itella_post_office'=>[
                                    0 => 'FI_itella_post_office'
                                ],
                                'FI_itella_courier'=>[
                                    0 => 'FI_itella_courier'
                                ],
                                'LT_omniva_parcel_machine'=>[
                                    0 => 'LT_omniva_parcel_machine'
                                ],
                                'LT_omniva_courier'=>[
                                    0 => 'LT_omniva_courier'
                                ],
                                'LT_dpd_parcel_machine'=>[
                                    0 => 'LT_dpd_parcel_machine'
                                ],
                                'LT_dpd_courier'=>[
                                    0 => 'LT_dpd_courier'
                                ],
                                'LV_omniva_parcel_machine'=>[
                                    0 => 'LV_omniva_parcel_machine'
                                ],
                                'LV_omniva_courier'=>[
                                    0 => 'LV_omniva_courier'
                                ],
                                'LV_dpd_parcel_machine'=>[
                                    0 => 'LV_dpd_parcel_machine'
                                ],
                                'LV_dpd_courier'=>[
                                    0 => 'LV_dpd_courier'
                                ]
                            ]
                        ],
                    ]
                );
            }
        }

        $setup->endSetup();
    }
}

