define([
    'uiComponent',
    'jquery',
    'ko',
    'mage/translate',
    'Magento_Checkout/js/model/quote',
    'Magento_Checkout/js/model/resource-url-manager',
    'mage/storage',
    'Magento_Checkout/js/model/payment-service',
    'Magento_Checkout/js/model/payment/method-converter',
    'Magento_Checkout/js/model/error-processor',
    'Magento_Checkout/js/model/full-screen-loader',
    'Magento_Checkout/js/action/select-billing-address',
    'Montonio_Shipping/js/lib/select2'
], function (Component, $, ko, $t, quote, resourceUrlManager, storage, paymentService, methodConverter, errorProcessor, fullScreenLoader, selectBillingAddressAction) {
    'use strict';

    var self;

    return Component.extend({
        defaults: {
            template: 'Montonio_Shipping/method',
            templateSelector: ko.observable(''),
            templateHtml: ko.observable(''),
            placeId: ko.observable(0),
            isVisible: ko.observable(false),
            pickupLocations: [],
            rendered: false,
            submitDisabled: false
        },
        initialize: function () {
            self = this;
            this._super();

            // subscribe to changing shipping method
            quote.shippingMethod.subscribe(function(method) {
                // if our method is selected, show the template
                var methodCode = method.method_code;
                if (method !== null && method.carrier_code === 'montonio_shipping' && methodCode.indexOf('courier', 0) === -1) {
                    var pickupLocations = [];
                    var places = [];
                    $('.montonio_shipping_points').closest('tr.row').hide();
                    places.push({"place_id": 0, 'name' : $t('Please select a place')});
                    pickupLocations.push({"label": ' ', 'places' : places});
                    jQuery.each(window.montonio_shipping_config.points[method.method_code], function(region, points) {
                        var places = [];
                        jQuery.each(points, function(place_id, name) {
                            places.push({"place_id": place_id, 'name' : name});

                        });
                        pickupLocations.push({"label": region, 'places' : places});

                    });
                    self.pickupLocations = pickupLocations;
                    self.templateSelector = method.method_code+'_box';
                    self.isVisible(true);

                    var template = $('tr#'+self.templateSelector);

                    // template has not yet been added
                    if (template.length === 0 && self.rendered) {
                        // create dummy row for our template
                        if ($('input[value="'+method.carrier_code+'_'+method.method_code+'"]').length) {
                            $('input[value="'+method.carrier_code+'_'+method.method_code+'"]').closest('tr.row').after('<tr id="' + self.templateSelector + '" class="row"></tr>');
                        }

                        var newTemplate = $('tr#'+self.templateSelector);

                        if (!self.submitDisabled){
                            setTimeout(function() {
                                $("#shipping-method-buttons-container").find("button").prop('disabled', true);
                                self.submitDisabled = true;
                            }, 200);
                        }

                        ko.utils.setHtml(newTemplate, self.templateHtml());  // set template
                        ko.applyBindings(self, newTemplate[0]);   // apply bindings to the template
                        $('.montonio_shipping_points').select2();

                    }
                    else {
                        var selectedPlace = template.find('select').val();
                        template.show();
                        $('.montonio_shipping_points').select2();

                        if (!self.submitDisabled && (selectedPlace == 0 || selectedPlace === undefined)){
                            setTimeout(function() {
                                $("#shipping-method-buttons-container").find("button").prop('disabled', true);
                                self.submitDisabled = true;

                            }, 200);
                        } else if(selectedPlace != 0) {
                            setTimeout(function() {
                                $("#shipping-method-buttons-container").find("button").prop('disabled', false);
                                self.submitDisabled = false;
                            }, 200);
                        }
                    }
                } else {
                    $("#shipping-method-buttons-container").find("button").prop('disabled', false);
                    self.submitDisabled = false;
                    $('.montonio_shipping_points').closest('tr.row').hide();
                    self.isVisible(false);
                }
            });

            // look for changes in the places dropdown
            this.placeChanged = function (obj, event) {
                var placeId = event.target.value;
                if (placeId !== 0) {
                    self.savePlace(placeId);
                } else if(placeId === 0) {
                    $("#shipping-method-buttons-container").find("button").prop('disabled', true);
                }
            };
        },
        savePlace: function(placeId) {
            var payload;

            if (!quote.billingAddress()) {
                selectBillingAddressAction(quote.shippingAddress());
            }
            var billingAddress = quote.billingAddress();
            if (billingAddress.custom_attributes) {
                if (!billingAddress.custom_attributes.montonio_shipping_point) {
                    delete(billingAddress['custom_attributes']);
                }
            }

            var shippingMethod = quote.shippingMethod();
            var shippingMethodCode = shippingMethod ? shippingMethod.method_code : null;
            var shippingCarrierCode = shippingMethod ? shippingMethod.carrier_code : null;

            _.extend(quote.shippingAddress, {
                custom_attributes: {
                    'montonio_shipping_point': placeId
                }
            });

            payload = {
                addressInformation: {
                    shipping_address: quote.shippingAddress(),
                    billing_address: quote.billingAddress(),
                    shipping_method_code: shippingMethodCode,
                    shipping_carrier_code: shippingCarrierCode,
                    extension_attributes: {
                        montonio_shipping_point: placeId
                    }
                }
            };

            fullScreenLoader.startLoader();
            return storage.post(
                resourceUrlManager.getUrlForSetShippingInformation(quote),
                JSON.stringify(payload)
            ).done(
                function (response) {
                    $("#shipping-method-buttons-container").find("button").prop('disabled', false);
                    self.submitDisabled = false;
                    fullScreenLoader.stopLoader();
                }
            ).fail(
                function (response) {
                    errorProcessor.process(response);
                    fullScreenLoader.stopLoader();
                }
            );
        },
        afterRender: function() {
            var template = $('#onepage-checkout-shipping-method-additional-load tr.placed-box');

            var pickupLocations = [];
            var places = [];
            places.push({"place_id": 0, 'name' : $t('Please select a place')});
            pickupLocations.push({"label": ' ', 'places' : places});

            self.templateHtml(template.html()); // copy the html into a variable
            template.remove();  // remove the original template
            self.rendered = true;

            var method = quote.shippingMethod();

            if (method !== null ) {
                var methodCode = method.method_code;
                if (method.carrier_code === 'montonio_shipping' && methodCode.indexOf('courier') === -1) {

                    jQuery.each(window.montonio_shipping_config.points[method.method_code], function(region, points) {
                        var places = [];
                        jQuery.each(points, function(place_id, name) {
                            places.push({"place_id": place_id, 'name' : name});

                        });
                        pickupLocations.push({"label": region, 'places' : places});

                    });
                    self.pickupLocations = pickupLocations;
                    self.isVisible(true);
                    if (!self.submitDisabled) {
                        $("#shipping-method-buttons-container").find("button").prop('disabled', true);
                        self.submitDisabled = true;
                    }
                    self.templateSelector = method.method_code+'_box';

                    // template has not yet been added
                    if (template.length === 1) {
                        var loadOptions = setInterval(function() {
                            if ($('input[value="'+method.carrier_code+'_'+method.method_code+'"]').length) {
                                clearInterval(loadOptions);
                                // create dummy row for our template
                                if ($('input[value="'+method.carrier_code+'_'+method.method_code+'"]').length) {
                                    $('input[value="'+method.carrier_code+'_'+method.method_code+'"]').closest('tr.row').after('<tr id="' + self.templateSelector + '" class="row"></tr>');
                                }

                                var newTemplate = $('#' +self.templateSelector);
                                ko.utils.setHtml(newTemplate, self.templateHtml());  // set template
                                if (newTemplate[0])
                                    ko.applyBindings(self, newTemplate[0]);   // apply bindings to the template

                                $('.montonio_shipping_points').select2();
                            }
                        }, 200);
                    }
                }

            }
        }
    });
});
